blackfridaytext

package module
v0.0.0-...-f4ea365 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 25, 2016 License: Apache-2.0 Imports: 2 Imported by: 6

README

blackfriday-text

A text renderer for the blackfriday markdown processor.

Usage
	import (
		"github.com/mschoch/blackfriday-text"
		"github.com/russross/blackfriday"
	)

	extensions := 0
	renderer := blackfridaytext.TextRenderer()
	output := blackfriday.Markdown(input, renderer, extensions)
License

Apache License Version 2.0

Why?

Why would you want to output markdown as text? Isn't it already text?

Yes, but sometimes you want to remove the formatting. For example, prior to feeding it into a text index, its helpful to remove the formatting characters.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func TextRenderer

func TextRenderer() blackfriday.Renderer

Types

type Text

type Text struct{}
func (options *Text) AutoLink(out *bytes.Buffer, link []byte, kind int)

func (*Text) BlockCode

func (options *Text) BlockCode(out *bytes.Buffer, text []byte, lang string)

func (*Text) BlockCodeNormal

func (options *Text) BlockCodeNormal(out *bytes.Buffer, text []byte, lang string)

func (*Text) BlockHtml

func (options *Text) BlockHtml(out *bytes.Buffer, text []byte)

func (*Text) BlockQuote

func (options *Text) BlockQuote(out *bytes.Buffer, text []byte)

func (*Text) CodeSpan

func (options *Text) CodeSpan(out *bytes.Buffer, text []byte)

func (*Text) DocumentFooter

func (options *Text) DocumentFooter(out *bytes.Buffer)

func (*Text) DocumentHeader

func (options *Text) DocumentHeader(out *bytes.Buffer)

func (*Text) DoubleEmphasis

func (options *Text) DoubleEmphasis(out *bytes.Buffer, text []byte)

func (*Text) Emphasis

func (options *Text) Emphasis(out *bytes.Buffer, text []byte)

func (*Text) Entity

func (options *Text) Entity(out *bytes.Buffer, entity []byte)

func (*Text) FootnoteItem

func (options *Text) FootnoteItem(out *bytes.Buffer, name, text []byte, flags int)

func (*Text) FootnoteRef

func (options *Text) FootnoteRef(out *bytes.Buffer, ref []byte, id int)

func (*Text) Footnotes

func (options *Text) Footnotes(out *bytes.Buffer, text func() bool)

func (*Text) GetFlags

func (options *Text) GetFlags() int

func (*Text) HRule

func (options *Text) HRule(out *bytes.Buffer)

func (*Text) Header

func (options *Text) Header(out *bytes.Buffer, text func() bool, level int, id string)

func (*Text) Image

func (options *Text) Image(out *bytes.Buffer, link []byte, title []byte, alt []byte)

func (*Text) LineBreak

func (options *Text) LineBreak(out *bytes.Buffer)
func (options *Text) Link(out *bytes.Buffer, link []byte, title []byte, content []byte)

func (*Text) List

func (options *Text) List(out *bytes.Buffer, text func() bool, flags int)

func (*Text) ListItem

func (options *Text) ListItem(out *bytes.Buffer, text []byte, flags int)

func (*Text) NormalText

func (options *Text) NormalText(out *bytes.Buffer, text []byte)

func (*Text) Paragraph

func (options *Text) Paragraph(out *bytes.Buffer, text func() bool)

func (*Text) RawHtmlTag

func (options *Text) RawHtmlTag(out *bytes.Buffer, text []byte)

func (*Text) Smartypants

func (options *Text) Smartypants(out *bytes.Buffer, text []byte)

func (*Text) StrikeThrough

func (options *Text) StrikeThrough(out *bytes.Buffer, text []byte)

func (*Text) Table

func (options *Text) Table(out *bytes.Buffer, header []byte, body []byte, columnData []int)

func (*Text) TableCell

func (options *Text) TableCell(out *bytes.Buffer, text []byte, align int)

func (*Text) TableHeaderCell

func (options *Text) TableHeaderCell(out *bytes.Buffer, text []byte, align int)

func (*Text) TableRow

func (options *Text) TableRow(out *bytes.Buffer, text []byte)

func (*Text) TitleBlock

func (options *Text) TitleBlock(out *bytes.Buffer, text []byte)

func (*Text) TocFinalize

func (options *Text) TocFinalize()

func (*Text) TocHeader

func (options *Text) TocHeader(text []byte, level int)

func (*Text) TripleEmphasis

func (options *Text) TripleEmphasis(out *bytes.Buffer, text []byte)

Jump to